@@ -325,7 +325,7 @@ xml_context_base* xlsx_sheet_context::create_child_context(xmlns_id_t ns, xml_to
         mp_child->transfer_common(*this);
         return mp_child.get();
     }
-    return NULL;
+    return nullptr;
 }
 
 void xlsx_sheet_context::end_child_context(xmlns_id_t ns, xml_token_t name, xml_context_base* child)
